Place Javascript files (`.js`, `.jsm`) for this app in this folder.

The files should be given the same name as the html files where they are used.  For example, if your template is called `index.html`, the script file should be called either `index.js` or `index.jsm`.  When you follow this naming convention, the Django-Mako-Plus framework will *automatically* include these files in your pages.  You do not need to code the `<script>` tags by hand.

See the DMP tutorial for information on the difference between `.js` and `.jsm` extensions.

Also ensure you have set up static files correctly.  More information about static files can be found in the `images/readme.md` file.
  
